summaryrefslogtreecommitdiff
path: root/sql/sql_get_diagnostics.cc
diff options
context:
space:
mode:
Diffstat (limited to 'sql/sql_get_diagnostics.cc')
-rw-r--r--sql/sql_get_diagnostics.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/sql/sql_get_diagnostics.cc b/sql/sql_get_diagnostics.cc
index b3ae423b914..197bf5e7a00 100644
--- a/sql/sql_get_diagnostics.cc
+++ b/sql/sql_get_diagnostics.cc
@@ -266,8 +266,8 @@ Condition_information::aggregate(THD *thd, const Diagnostics_area *da)
Item *
Condition_information_item::make_utf8_string_item(THD *thd, const String *str)
{
- /* Default is utf8 character set and utf8_general_ci collation. */
- CHARSET_INFO *to_cs= &my_charset_utf8_general_ci;
+ /* Default is utf8 character set and utf8mb3_general_ci collation. */
+ CHARSET_INFO *to_cs= &my_charset_utf8mb3_general_ci;
/* If a charset was not set, assume that no conversion is needed. */
CHARSET_INFO *from_cs= str->charset() ? str->charset() : to_cs;
String tmp(str->ptr(), str->length(), from_cs);